package com.ruoyi.brewery.service;

import java.util.List;

import com.ruoyi.brewery.domain.PopularStyleVO;
import com.ruoyi.brewery.domain.WyBeer;

/**
 * 啤酒Service接口
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
public interface IWyBeerService 
{
    /**
     * 查询啤酒
     * 
     * @param id 啤酒主键
     * @return 啤酒
     */
    public WyBeer selectWyBeerById(Long id);

    /**
     * 查询啤酒列表
     * 
     * @param wyBeer 啤酒
     * @return 啤酒集合
     */
    public List<WyBeer> selectWyBeerList(WyBeer wyBeer);

    List<WyBeer> top10BeersList(WyBeer wyBeer);

    List<WyBeer> selectWyBeerListWithData(WyBeer wyBeer);

    List<PopularStyleVO> selectPopularStyles();

    /**
     * 新增啤酒
     * 
     * @param wyBeer 啤酒
     * @return 结果
     */
    public int insertWyBeer(WyBeer wyBeer);

    /**
     * 修改啤酒
     * 
     * @param wyBeer 啤酒
     * @return 结果
     */
    public int updateWyBeer(WyBeer wyBeer);

    /**
     * 批量删除啤酒
     * 
     * @param ids 需要删除的啤酒主键集合
     * @return 结果
     */
    public int deleteWyBeerByIds(Long[] ids);

    /**
     * 删除啤酒信息
     * 
     * @param id 啤酒主键
     * @return 结果
     */
    public int deleteWyBeerById(Long id);

    List<WyBeer> seleteWyBeerByIds(Long[] ids);
}
